@@ -109,7 +109,7 @@ class Pihkal(object):
             '5-ethoxy-2-methoxy-4-methylamphetamine': 'CCOC1=CC(=C(OC)C=C1C)CC(C)N',
             '2-amino-1-(3,4-methylenedioxyphenyl)butane': 'CCC(N)CC1=CC=C2OCOC2=C1',
             '3-methoxy-4,5-methylenedioxyphenethylamine': 'COC1=C2OCOC2=CC(=C1)CCN',
-            'mescaline': 'C[O:7][C:2]1=[CH:1][C:6](=[CH:5][C:4](=[C:3]1[O:9]C)[O:20]C)[CH2:10][CH2:11][NH2:12]',
+            'mescaline': 'COC1=CC(=CC(=C1OC)OC)CCN',
             '4-methoxyamphetamine': 'CC(CC1=CC=C(C=C1)OC)N',
             '2,n-dimethyl-4,5-methylenedioxyamphetamine': 'CNC(C)CC1=C(C)C=C2OCOC2=C1',
             'methallylescaline': 'COC1=CC(=CC(=C1OCC(C)=C)OC)CCN',
@@ -296,7 +296,7 @@ class Pihkal(object):
             '5-ethoxy-2-methoxy-4-methylamphetamine': '[#6]-[#6]-[#8]-[#6]1:[#6]:[#6](:[#6](-[#8]-[#6]):[#6]:[#6]:1-[#6])-[#6]-[#6](-[#6])-[#7]',
             '2-amino-1-(3,4-methylenedioxyphenyl)butane': '[#6]-[#6]-[#6](-[#7])-[#6]-[#6]1:[#6]:[#6]:[#6]2-[#8]-[#6]-[#8]-[#6]:2:[#6]:1',
             '3-methoxy-4,5-methylenedioxyphenethylamine': '[#6]-[#8]-[#6]1:[#6]2-[#8]-[#6]-[#8]-[#6]:2:[#6]:[#6](:[#6]:1)-[#6]-[#6]-[#7]',
-            'mescaline': '[#6]-[#8:7]-[#6:2]1:[#6H:1]:[#6:6](:[#6H:5]:[#6:4](:[#6:3]:1-[#8:9]-[#6])-[#8:20]-[#6])-[#6H2:10]-[#6H2:11]-[#7H2:12]',
+            'mescaline': '[#6]-[#8]-[#6]1:[#6]:[#6](:[#6]:[#6](:[#6]:1-[#8]-[#6])-[#8]-[#6])-[#6]-[#6]-[#7]',
             '4-methoxyamphetamine': '[#6]-[#6](-[#6]-[#6]1:[#6]:[#6]:[#6](:[#6]:[#6]:1)-[#8]-[#6])-[#7]',
             '2,n-dimethyl-4,5-methylenedioxyamphetamine': '[#6]-[#7]-[#6](-[#6])-[#6]-[#6]1:[#6](-[#6]):[#6]:[#6]2-[#8]-[#6]-[#8]-[#6]:2:[#6]:1',
             'methallylescaline': '[#6]-[#8]-[#6]1:[#6]:[#6](:[#6]:[#6](:[#6]:1-[#8]-[#6]-[#6](-[#6])=[#6])-[#8]-[#6])-[#6]-[#6]-[#7]',
